Learn R Programming

degross (version 0.9.0)

print.degrossData: Print a 'degrossData' object.

Description

Print a summary of the information contained in a degrossData.object used by degross for density estimation from tabulated frequency and moment data.

Usage

# S3 method for degrossData
print(x, ...)

Arguments

...

Possible additional printing options for a matrix object.

Value

Print the tabulated summary statistics contained in the degrossData.object x, with additional information on the total sample size, numbers of small and big bins with their limits, the number of B-splines planned for density estimation using degross.

References

Lambert, P. (2021) Moment-based density and risk estimation from grouped summary statistics. arXiv:2107.03883.

See Also

degross, degrossData

Examples

Run this code
# NOT RUN {
sim = simDegrossData(n=3500, plotting=TRUE)
obj.data = degrossData(Big.bins=sim$Big.bins, freq.j=sim$freq.j, m.j=sim$m.j)
print(obj.data)

# }

Run the code above in your browser using DataLab