lpost, lpost.ni : value of the log-posterior based on the given small bin frequencies n.i and the tabulated sample moments.
lpost.mj : value of the log-posterior based on the big bin frequencies degross.data$freq.j and the tabulated sample moments.
llik.ni : multinomial log-likelihood based on the given small bin frequencies n.i.
llik.mj : multinomial log-likelihood based on the big bin frequencies degross.data$freq.j.
moments.penalty : log of the joint (asymptotic) density for the observed sample moments.
penalty : \(\log p(\phi|\tau) + \log p(\tau)\).
Score, Score.ni : score (w.r.t. \(\phi\)) of lpost.ni.
Score.mj : score (w.r.t. \(\phi\)) of lpost.mj.
Fisher & Fisher.ni: information matrix (w.r.t. \(\phi\)) of lpost.ni.
Fisher.mj : information matrix (w.r.t. \(\phi\)) of lpost.mj.
M.j : theoretical moments of the density (resulting from \(\phi\)) within a big bin.
pi.i : small bin probabilities.
ui : small bin midpoints.
delta : width of the small bins.
gamma.j : Big bin probabilities.
tau : reminder of the value of the roughness penalty parameter \(\tau\).
phi : reminder of the vector of spline parameters (defining the density).
n.i : reminder of the small bin frequencies given as input.