Possible additional printing options for a matrix object.
Value
Print the tabulated summary statistics contained in the degrossData.objectx, with additional information on the total sample size, numbers of small and big bins with their limits, the number of B-splines planned for density estimation using degross.
References
Lambert, P. (2021) Moment-based density and risk estimation from grouped summary statistics. arXiv:2107.03883.